{
  pkgs,
  hostName,
  user,
  version,
  ...
}:

{
  boot = {
    kernelPackages = pkgs.linuxKernel.packages.linux_rpi4;
    initrd.availableKernelModules = [
      "xhci_pci"
      "usbhid"
      "usb_storage"
    ];
    loader = {
      grub.enable = false;
      generic-extlinux-compatible.enable = true;
    };
  };

  environment.systemPackages = with pkgs; [
    vim
  ];

  fileSystems = {
    "/" = {
      device = "/dev/disk/by-label/NIXOS_SD";
      fsType = "ext4";
      options = [ "noatime" ];
    };
  };

  hardware.enableRedistributableFirmware = true;

  networking = {
    inherit hostName;
    networkmanager.enable = true;
  };

  services.openssh.enable = true;

  system.stateVersion = version;

  users = {
    mutableUsers = false;
    users.${user.name} = {
      isNormalUser = true;
      password = user.password;
      extraGroups = [ "wheel" ];
    };
  };
}
